======
pyskyq
======

A Python API for controlling a Sky Q Box.


Contents
========

.. toctree::
   :maxdepth: 2

   Readme <readme>
   License <license>
   Authors <authors>
   Release Notes <changelog>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
